Package: easyPSID
Title: Reading, Formatting, and Organizing the Panel Study of Income
        Dynamics (PSID)
Version: 0.1.3
Authors@R: person("Brian", "Aronson",email = "bdaronson@gmail.com", role = c("aut", "cre"))
Description: Provides various functions for reading and preparing the Panel Study of Income Dynamics (PSID) for longitudinal analysis, including functions that read the PSID's fixed width format files directly into R, rename all of the PSID's longitudinal variables so that recurring variables have consistent names across years, simplify assembling longitudinal datasets from cross sections of the PSID Family Files, and export the resulting PSID files into file formats common among other statistical programming languages ('SAS', 'STATA', and 'SPSS').
Depends: R (>= 3.0.1), stringr (>= 1.0.0), LaF (>= 0.6.0), foreign (>=
        0.8-67)
License: MIT + file LICENSE
Encoding: UTF-8
Suggests: readxl (>= 1.4.0), testthat (>= 3.0.0)
Config/testthat/edition: 3
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-08-04 14:54:57 UTC; bdaro
Author: Brian Aronson [aut, cre]
Maintainer: Brian Aronson <bdaronson@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-04 17:30:07 UTC
Built: R 4.6.0; ; 2026-08-04 19:36:11 UTC; unix
