# Generated by roxygen2: do not edit by hand

export(convert_from_rds)
export(convert_to_rds)
export(create_custom_panel)
export(create_extract)
export(find_description)
export(find_name)
export(find_years)
export(rename_fam_vars)
export(rename_ind_vars)
export(unzip_all_files)
importFrom(LaF,laf_open_fwf)
importFrom(foreign,write.dta)
importFrom(foreign,write.foreign)
importFrom(stringr,str_extract)
importFrom(stringr,str_match)
importFrom(stringr,str_match_all)
importFrom(utils,object.size)
importFrom(utils,unzip)
