% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/2convert_to_rds.R
\name{convert_to_rds}
\alias{convert_to_rds}
\title{Convert all PSID files from .txt format to .rds format}
\usage{
convert_to_rds(in_direc, out_direc)
}
\arguments{
\item{in_direc}{Directory containing unzipped PSID .txt and .do files}

\item{out_direc}{Directory to place PSID .rds files into}
}
\description{
Converts all PSID fixed width format .txt files in a selected directory into .rds format. This function expects the ASCII .txt file and matching Stata .do definition file contained in each PSID packaged-data .zip download. It does not read Stata .dta files. All files must retain the names they had when first unzipped.
}
\examples{
convert_to_rds(
    in_direc=system.file("extdata","unzip_dir", package = "easyPSID"),
    out_direc=tempdir()
)
}
\keyword{PSID}
